/*
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.network.synchronization.bean;

/**
 * The message is transferred between peers in the same peer group.
 * 
 * Different messages have different mode values, such as ERROR_MESSAGE, JOINGROUP_MESSAGE, etc.
 * 
 * The header of the message carries the info of the sending peer.
 * 
 * And all the subjects transferred by this message are stored in attributes map.
 * 
 * 
 * @author TCSDESIGNER
 * @version 1.0
 */
public class Message extends AttributeSupportedObject {

    /**
     * Represents the error message.
     */
    public static final int ERROR_MESSAGE = 0;
    
    /**
     * Represents the message requests to join a peer group.
     */
    public static final int JOINGROUP_MESSAGE = 1;
    
    /**
     * Represents the message requests to leave a peer group.
     */
    public static final int LEAVEGROUP_MESSAGE = 2;
    
    /**
     * Represents the message sended by the user application.
     */
    public static final int APPLICATION_MESSAGE = 3;    
    
    /**
     * Represents the message to request a particular message with specified id.
     */
    public static final int REQUEST_MESSAGE = 4;
    
    /**
     * Represents the message to forward a particular message.
     */
    public static final int FORWARD_MESSAGE = 5;
    
    /**
     * Represents the message to communicate with other peers for synchronization.
     */
    public static final int COMMUNICATE_MESSAGE = 6;
    
    /**
     * Represents the message sended by one peer to keep it alive.
     */
    public static final int KEEPALIVE_MESSAGE = 7;
    
    /**
     * Represents the message replies to the JOINGROUP_MESSAGE.
     */
    public static final int REPLYJOIN_MESSAGE = 8;
    
    /**
     * Represents the message to lookup all the groups in the network.
     */
    public static final int LOOKUPGROUP_MESSAGE = 9;
    
    /**
     * Represents the message sended to a destinative peer.
     */
    public static final int DESTINATIVE_MESSAGE = 10;
    
    /**
     * The identifier of the message.
     * Initialized in constructor, immutable, not null.
     */
    private String messageId = null;
    
    /**
     * Represents the type of this message.
     */
    private int mode;
    
    /**
     * Represents the header of this message.
     */
    private MessageHeader header = null;       
    
    /**
     * The constructor.  
     * 
     * @param messageId the id of this message
     * @param header the header of this message
     * @param mode the mode of this message
     * 
     */
    public Message(String messageId, MessageHeader header, int mode) {        
    }
    
    /**
     * Return the id of this message.
     * Simply return id;
     * @return the id of this message
     */
    public String getMessageId() {
        return messageId;
    }    
    
    /**
     * Return ths mode of this message. 
     * @return ths mode of this message
     */
    public int  getMode() {
        return mode;
    }
    
    /**
     * Return the header of this message.
     * @return the header of this message
     */
    public MessageHeader getHeader() {
        return header;
    }
    
}
