/*
 * Copyright (c) 2005 TopCoder, Inc., All Rights Reserved
 */
package com.topcoder.network.synchronization.defaultimpl.listener;

import java.util.Collection;
import java.util.HashMap;
import java.util.Map;

import com.topcoder.network.synchronization.bean.Message;
import com.topcoder.network.synchronization.protocol.MessageListener;
import com.topcoder.network.synchronization.protocol.PeerGroupService;

/**
 * The default message listener for global peer group service.
 * It deals only two message types:
 * 1. The message that looks up all peer groups information in the subnet. 	  
 * 	  For this message, just send a destinative message containing the current synchronized peer group information.
 *   
 * 2. The destinative message that containing the peer groups info. 
 * 	  For this message, Add the PeerGroupInfo instance into groups list.
 *    
 * @author TCSDESIGNER
 * @version 1.0
 */
public class GlobalMessageListener extends MessageListener {        

    /**
     * Represents the global group service
     */
    private PeerGroupService globalService = null;
    
    /**
     * Represents the peer groups info received from the global receiver.
     */
    private Map groups = new HashMap();
    
    /**
     * Construct this object with global service.
     * 
     * @param globalService the global service
     */
    public GlobalMessageListener(PeerGroupService globalService) {
        
    }    
    
    /**
     * Return the groups received from global receiver. 
     * 
     * @return the groups received from global receiver.
     */
    public Collection getGroups() {
        return groups.values();
    }
    
    /**
     * Clear the received groups in this listener.
     * 
     * groups.clear();  
     *
     */
    public void clear() {
        
    }
    
    /**
     * Deal the message from the global receiver.
     * 
     * 1. if the message is a LOOKUPGROUP_MESSAGE, send a DESTINATIVE_MESSAGE message containing all the peer groups 
     * this peer has joined to the sender of the LOOKUPGROUP_MESSAGE
     * 
     * 2. if the message is a DESTINATIVE_MESSAGE and the destination is this peer, add all the peer groups in this
     * message to the groups map.
     *
     * 3. if the next listener is not null, forward the message to it. 
     */
    public void dealMessage(Message message) {
        
    }    
}
